@@ -1,17 +1,15 @@
 import org.parboiled.common.FileUtils;
 import org.parboiled.common.ImmutableList;
-import org.scalatest.testng.TestNGWrapperSuite;
+import org.scalatestplus.testng.TestNGWrapperSuite;
 
 import java.io.File;
 import java.io.IOException;
 
-import static scala.collection.JavaConversions.collectionAsScalaIterable;
-
 @SuppressWarnings("unchecked")
 public class ExamplesJavaTestWrapper extends TestNGWrapperSuite {
 
     public ExamplesJavaTestWrapper() throws IOException {
-        super(collectionAsScalaIterable(ImmutableList.of(getSuiteFileName())).toList());
+        super(new org.parboiled.JavaCollectionWrapper(ImmutableList.of(getSuiteFileName())).toList());
     }
     
     public static String getSuiteFileName() throws IOException {
