@@ -17,7 +17,7 @@
 package org.parboiled.examples.calculators
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert.assertEquals
 import org.parboiled.matchers.Matcher
 import org.parboiled.trees.GraphUtils
@@ -27,6 +27,7 @@ import org.parboiled.common.Predicates
 import org.parboiled.scala.parserunners.ReportingParseRunner
 
 class SimpleCalculatorTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
   
   val parser = new SimpleCalculator1() {
     override val buildParseTree = true
@@ -35,7 +36,7 @@ class SimpleCalculatorTest extends ParboiledTest with TestNGSuiteLike {
   type Result = Int
 
   @Test
-  def testSimpleCalculatorMatcherBuilding() {
+  def testSimpleCalculatorMatcherBuilding(): Unit = {
     assertEquals(GraphUtils.printTree(parser.InputLine.matcher, new ToStringFormatter[Matcher](),
       Predicates.alwaysTrue(), Filters.preventLoops),
        """|InputLine
@@ -75,8 +76,8 @@ class SimpleCalculatorTest extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testCalculations() {
-    def test(input: String, expected: Int) {
+  def testCalculations(): Unit = {
+    def test(input: String, expected: Int): Unit = {
       parse(ReportingParseRunner(parser.InputLine), input) {
         assertEquals(result.get, expected)
       }
@@ -97,4 +98,4 @@ class SimpleCalculatorTest extends ParboiledTest with TestNGSuiteLike {
     test("((1+2)*3-(4-5))/5", 2)
   }
 
-}
\ No newline at end of file
+}
