@@ -17,20 +17,21 @@
 package org.parboiled.examples.calculators
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert.assertEquals
 import org.parboiled.scala.parserunners._
 import org.parboiled.scala.testing.ParboiledTest
 import org.parboiled.common.StringBuilderSink
 
 class TracingTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
 
   val parser = new SimpleCalculator1
 
   type Result = Int
 
   @Test
-  def testTraceParse() {
+  def testTraceParse(): Unit = {
     val log = new StringBuilderSink 
     parse(TracingParseRunner(parser.InputLine).filter(Rules.only(parser.Factor, parser.Term)).log(log), "1+2") {
       assertEquals(log.toString,
@@ -44,7 +45,7 @@ InputLine/Expression/Term/Factor, matched, cursor at 1:2 after "1"
   }
     
   @Test
-  def testTraceParse2() {
+  def testTraceParse2(): Unit = {
     val log = new StringBuilderSink 
     parse(TracingParseRunner(parser.InputLine).filter(Rules.below(parser.Factor) && !Rules.below(parser.Digits)).log(log), "1+2") {
       assertEquals(log.toString,
@@ -59,4 +60,4 @@ InputLine/Expression/Term/Factor/Number/Digits, matched, cursor at 1:2 after "1"
     }
   }
 
-}
\ No newline at end of file
+}
