@@ -17,18 +17,20 @@
 package org.parboiled.examples.json
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert.assertEquals
 import org.parboiled.scala.testing.ParboiledTest
 import org.parboiled.scala.parserunners.ReportingParseRunner
 
 class JsonParserTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
+
   val parser = new JsonParser1()
 
   type Result = parser.AstNode
 
   @Test
-  def testJsonParser() {
+  def testJsonParser(): Unit = {
     val json = """|{
                   |  "simpleKey" : "some value",
                   |  "key with spaces": null,
@@ -68,7 +70,7 @@ class JsonParserTest extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testJsonParserError() {
+  def testJsonParserError(): Unit = {
     failParse(ReportingParseRunner(parser.Json), "XYZ") {
       assertEquals(errors,
         """|Invalid input 'X', expected Json (line 1, pos 1):
@@ -82,12 +84,12 @@ class JsonParserTest extends ParboiledTest with TestNGSuiteLike {
   def printAst(node: JsonParser1#AstNode, indent: String = ""): String = node match {
     case n: JsonParser1#ObjectNode => "{\n" + (for (sub <- n.members) yield printAst(sub, indent + "  ")).mkString + indent + "}"
     case n: JsonParser1#MemberNode => indent + '"' + n.key + "\" : " + printAst(n.value, indent) + "\n"
-    case n: JsonParser1#ArrayNode => '[' + (for (sub <- n.elements) yield printAst(sub, indent + "  ")).mkString(", ") + "]"
-    case n: JsonParser1#StringNode => '"' + n.text + '"'
+    case n: JsonParser1#ArrayNode => "[" + (for (sub <- n.elements) yield printAst(sub, indent + "  ")).mkString(", ") + "]"
+    case n: JsonParser1#StringNode => "\"" + n.text + '"'
     case n: JsonParser1#NumberNode => n.value.toString
     case parser.True => "true"
     case parser.False => "false"
     case parser.Null => "null"
   }
 
-}
\ No newline at end of file
+}
