@@ -33,10 +33,10 @@ public class CurrentCharTest {
     }
 
     @Test
-    public void test() {
+    public void testCurrentChar() {
         Parser parser = Parboiled.createParser(Parser.class);
         assertFalse(new RecoveringParseRunner(parser.Clause()).run("a").hasErrors());
         assertTrue(new RecoveringParseRunner(parser.Clause()).run("b").hasErrors());
     }
 
-}
\ No newline at end of file
+}
