@@ -23,7 +23,7 @@ import java.lang.String
 /**
  * A rule matching one single character.
  */
-class CharRule(val c: Char) extends Rule0(new CharMatcher(c).label('\'' + escape(c) + '\'')) {
+class CharRule(val c: Char) extends Rule0(new CharMatcher(c).label(s"'${escape(c)}'")) {
 
   /**
    * Creates a rule matching the range of characters between the character of this rule and the given character
@@ -31,7 +31,7 @@ class CharRule(val c: Char) extends Rule0(new CharMatcher(c).label('\'' + escape
    */
   override def -(upperBound: String) = {
     require(upperBound != null && upperBound.length == 1)
-    new Rule0(new CharRangeMatcher(c, upperBound.charAt(0)).label(c + ".." + upperBound))
+    new Rule0(new CharRangeMatcher(c, upperBound.charAt(0)).label(s"${c}..${upperBound}"))
   }
 
 }
