@@ -17,11 +17,12 @@
 package org.parboiled.scala
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert.assertEquals
 import testing.ParboiledTest
 
 class BugIn101Test extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
 
   type Result = Int
 
@@ -34,10 +35,10 @@ class BugIn101Test extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testNTimes() {
+  def testNTimes(): Unit = {
     parse(ReportingParseRunner(parser.A), "any") {
       assertEquals(parseTree,"[A] 'a'\n")
     }
   }
 
-}
\ No newline at end of file
+}
