@@ -17,11 +17,12 @@
 package org.parboiled.scala
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.parboiled.errors.ParserRuntimeException
 import testing.ParboiledTest
 
 class EOIMatchingTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
 
   class EOIMatchingParser extends Parser {
     def Clause = rule { oneOrMore(EOI) }
@@ -32,11 +33,11 @@ class EOIMatchingTest extends ParboiledTest with TestNGSuiteLike {
     expectedExceptionsMessageRegExp = "Parser read more than 100K chars beyond EOI, " +
       "verify that your grammar does not consume EOI indefinitely!"
   )
-  def testEOIMatchingParser() {
+  def testEOIMatchingParser(): Unit = {
     val rule = new EOIMatchingParser().Clause
     parse(ReportingParseRunner(rule), "") {
       fail("Exception expected")
     }
   }
 
-}
\ No newline at end of file
+}
