@@ -17,12 +17,13 @@
 package org.parboiled.scala
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert._
 import testing.ParboiledTest
 import org.parboiled.matchers.FirstOfStringsMatcher
 
 class FirstOfStringsTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
 
   class TestParser extends Parser {
     def Fast = rule { "Alpha" | "Bravo" | "Charlie" }
@@ -37,11 +38,11 @@ class FirstOfStringsTest extends ParboiledTest with TestNGSuiteLike {
   val parser = new TestParser
 
   @Test
-  def testFast() {
+  def testFast(): Unit = {
     assertTrue(parser.Fast.matcher.isInstanceOf[FirstOfStringsMatcher]);
     assertFalse(parser.Slow1.matcher.isInstanceOf[FirstOfStringsMatcher]);
     assertFalse(parser.Slow2.matcher.isInstanceOf[FirstOfStringsMatcher]);
     assertFalse(parser.Slow3.matcher.isInstanceOf[FirstOfStringsMatcher]);
   }
 
-}
\ No newline at end of file
+}
