@@ -17,11 +17,12 @@
 package org.parboiled.scala
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert.assertEquals
 import testing.ParboiledTest
 
 class LoopedReductionRuleTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
 
   type Result = Expression
 
@@ -53,7 +54,7 @@ class LoopedReductionRuleTest extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testLoopedReductionRule() {
+  def testLoopedReductionRule(): Unit = {
     parse(ReportingParseRunner(parser.IntsAndDoubles), "1 + 0.3 + 0.3 + 0.3") {
       assertEquals(parseTree,
         """[IntsAndDoubles, {DoubleExpression(1.9000000000000001)}] '1 + 0.3 + 0.3 + 0.3'
