@@ -17,11 +17,12 @@
 package org.parboiled.scala
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert.assertEquals
 import testing.ParboiledTest
 
 class NTimesTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
 
   type Result = Int
 
@@ -38,7 +39,7 @@ class NTimesTest extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testNTimes() {
+  def testNTimes(): Unit = {
     parse(ReportingParseRunner(parser.AsAndBs), "abbbbb123") {
       assertEquals(parseTree,
          """[AsAndBs, {6}] 'abbbbb123'
@@ -59,4 +60,4 @@ class NTimesTest extends ParboiledTest with TestNGSuiteLike {
     }
   }
 
-}
\ No newline at end of file
+}
