@@ -17,7 +17,7 @@
 package org.parboiled.scala
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert.assertEquals
 import org.parboiled.matchers.Matcher
 import org.parboiled.trees.GraphUtils
@@ -26,6 +26,7 @@ import org.parboiled.support.{Filters, ToStringFormatter}
 import org.parboiled.common.Predicates
 
 class RecursionTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
 
   class RecursionParser extends Parser {
     def LotsOfAs: Rule0 = rule {ignoreCase('a') ~ optional(LotsOfAs)}
@@ -36,7 +37,7 @@ class RecursionTest extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testRuleTreeConstruction() {
+  def testRuleTreeConstruction(): Unit = {
     val rule = parser.LotsOfAs
     assertEquals(GraphUtils.printTree(rule.matcher, new ToStringFormatter[Matcher], Predicates.alwaysTrue(),
       Filters.preventLoops()),
@@ -48,7 +49,7 @@ class RecursionTest extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testRecursion() {
+  def testRecursion(): Unit = {
     parse(ReportingParseRunner(parser.LotsOfAs), "aAAAa") {
       assertEquals(parseTree,
          """|[LotsOfAs] 'aAAAa'
@@ -70,4 +71,4 @@ class RecursionTest extends ParboiledTest with TestNGSuiteLike {
     }
   }
 
-}
\ No newline at end of file
+}
