@@ -17,7 +17,7 @@
 package org.parboiled.scala
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert.assertEquals
 import org.parboiled.matchers.Matcher
 import org.parboiled.support.ToStringFormatter
@@ -25,6 +25,7 @@ import org.parboiled.trees.GraphUtils
 import testing.ParboiledTest
 
 class SimpleTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
 
   class SimpleParser extends Parser {
     def Clause = rule {Digit ~ ClauseRest ~ EOI}
@@ -41,7 +42,7 @@ class SimpleTest extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testRuleTreeConstruction() {
+  def testRuleTreeConstruction(): Unit = {
     val rule = parser.Clause
     assertEquals(GraphUtils.printTree(rule.matcher, new ToStringFormatter[Matcher]),
        """|Clause
@@ -59,7 +60,7 @@ class SimpleTest extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testSimpleParse() {
+  def testSimpleParse(): Unit = {
     parse(ReportingParseRunner(parser.Clause), "1+2a") {
       assertEquals(parseTree,
          """|[Clause] '1+2a'
@@ -76,4 +77,4 @@ class SimpleTest extends ParboiledTest with TestNGSuiteLike {
     }
   }
 
-}
\ No newline at end of file
+}
