@@ -17,11 +17,12 @@
 package org.parboiled.scala
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert.assertEquals
 import testing.ParboiledTest
 
 class SyntacticPredicateTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
 
   class TestParser extends Parser {
     def Clause = rule { Number ~ &("1") ~ Number ~ !"5" ~ Number }
@@ -35,7 +36,7 @@ class SyntacticPredicateTest extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testSyntacticPredicates() {
+  def testSyntacticPredicates(): Unit = {
     parse(ReportingParseRunner(parser.Clause), "216") {
       assertEquals(parseTree,
         """|[Clause] '216'
@@ -46,4 +47,4 @@ class SyntacticPredicateTest extends ParboiledTest with TestNGSuiteLike {
     }
   }
 
-}
\ No newline at end of file
+}
