@@ -17,11 +17,12 @@
 package org.parboiled.scala
 
 import org.testng.annotations.Test
-import org.scalatest.testng.TestNGSuiteLike
+import org.scalatestplus.testng.TestNGSuiteLike
 import org.testng.Assert.assertEquals
 import testing.ParboiledTest
 
 class WithContextTest extends ParboiledTest with TestNGSuiteLike {
+  // def fail(message: String): Nothing = super.fail(message)(null)
 
   class TestParser extends Parser {
     def Clause = rule (
@@ -43,7 +44,7 @@ class WithContextTest extends ParboiledTest with TestNGSuiteLike {
   }
 
   @Test
-  def testWithContext() {
+  def testWithContext(): Unit = {
     parse(ReportingParseRunner(parser.Clause), "A5") {
       assertEquals(parseTree,
          """|[Clause, {8}] 'A5'
@@ -55,4 +56,4 @@ class WithContextTest extends ParboiledTest with TestNGSuiteLike {
     }
   }
 
-}
\ No newline at end of file
+}
